Clazz.declarePackage("JS");
Clazz.load(["JS.LayoutManager"], "JS.FlowLayout", null, function(){
var c$ = Clazz.declareType(JS, "FlowLayout", JS.LayoutManager);
});
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
